@@ -60,14 +60,6 @@ typedef struct _ArcBall_t ArcBall_t;
 typedef enum {attr_alpha,attr_float,attr_int,attr_bool} attr_data_type;
 typedef enum {smyrna_all,smyrna_2D,smyrna_3D,smyrna_fisheye,smyrna_all_but_fisheye} smyrna_view_mode;
 
-
-typedef struct{
-    int keyVal;
-    int down;
-}keymap_t;
-
-
-
 typedef struct {
 	size_t index;
 	char* name;
@@ -106,7 +98,6 @@ typedef struct
 
     typedef struct {
 	size_t schemacount; // number of colors
-	int smooth;            /* if true, interpolate */
 	colorschema *s;
     } colorschemaset;
 
@@ -338,7 +329,6 @@ typedef struct
 	void *glutfont;
 	glCompColor nodelabelcolor;
 	glCompColor edgelabelcolor;
-	int labelwithdegree;
 	int labelnumberofnodes;
 	int labelshownodes;
 	int labelshowedges;
@@ -347,11 +337,11 @@ typedef struct
 	char *initFileName;	//file name from command line
 	int initFile;
 	int drawSplines;
-	colorschemaset *colschms;
+	colorschemaset colschms;
 	char *template_file;
 	GtkComboBox *graphComboBox;	/*pointer to graph combo box at top right */
 	ArcBall_t *arcball;
-	keymap_t keymap;
+	int keyVal; ///< depressed key or 0 if none
 	mouse_action_t* mouse_actions; ///< customizable mouse interaction list
 	size_t mouse_action_count;
 	float nodeScale;
@@ -361,7 +351,6 @@ typedef struct
     } ViewInfo;
 
     extern ViewInfo *view;
-    extern GtkMessageDialog *Dlg;
     extern char *smyrnaPath(char *suffix);
 
     extern void glexpose(void);
