@@ -13,15 +13,12 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#ifdef HAVE_SEARCH_H
-#include <search.h>
-#endif
 #include <ctype.h>
+#include <util/agxbuf.h>
 typedef struct {
     char *name;
     unsigned char h, s, b;
