@@ -12,12 +12,12 @@
 
 #pragma once
 
+#include <util/agxbuf.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include <agxbuf.h>
-
     union HTMLSTYPE;
     typedef struct htmlparserstate_s htmlparserstate_t;
     typedef struct htmlscan_s htmlscan_t;
