@@ -10,7 +10,6 @@
 
 
 #include "config.h"
-#include <cgraph/alloc.h>
 #include <cgraph/list.h>
 #include <common/geom.h>
 #include <math.h>
@@ -18,6 +17,7 @@
 #include <neatogen/adjust.h>
 #include <stddef.h>
 #include <stdbool.h>
+#include <util/alloc.h>
 
 /* For precision, scale up before algorithms, then scale down */
 #define SCALE 10   
