@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -19,8 +19,6 @@ extern "C" {
 typedef struct {
 	float **A;
 	int n;
-	int *iArray1;
-	int *iArray2;
 	float *fArray1;
 	float *fArray2;
 	float *fArray3;
