@@ -56,7 +56,6 @@
 */
 
 #define STANDALONE
-#include <cgraph/alloc.h>
 #include <cgraph/list.h>
 #include <limits.h>
 #include <sparse/general.h>
@@ -64,6 +63,7 @@
 #include <sparse/mq.h>
 #include <stdbool.h>
 #include <string.h>
+#include <util/alloc.h>
 
 static double get_mq(SparseMatrix A, int *assignment, int *ncluster0, double *mq_in0, double *mq_out0, double **dout0){
   /* given a symmetric matrix representation of a graph and an assignment of nodes into clusters, calculate the modularity quality.
