@@ -16,13 +16,13 @@
 #define _GNU_SOURCE
 #include "config.h"
 #include <assert.h>
-#include <cgraph/agxbuf.h>
 #include <math.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <errno.h>
+#include <util/agxbuf.h>
 #include <util/prisize_t.h>
 
 #include <common/macros.h>
@@ -297,8 +297,6 @@
 #define RENDERER_COLOR_TYPE RGBA_BYTE
 typedef enum { FORMAT_POV, } format_type;
 
-//#define DEBUG
-
 //TODO: check why this dot file does not work (90 rotated)
 //   /usr/share/graphviz/graphs/directed/NaN.gv
 //TODO: add Texttures
@@ -551,11 +549,11 @@ static void pov_ellipse(GVJ_t * job, pointf * A, int filled)
 	z = layerz - 6;
 
 	// A[0] center, A[1] corner of ellipse
-	float cx = (A[0].x + job->translation.x) * job->scale.x;
-	float cy = (A[0].y + job->translation.y) * job->scale.y;
-	float rx = (A[1].x - A[0].x) * job->scale.x;
-	float ry = (A[1].y - A[0].y) * job->scale.y;
-	float w = job->obj->penwidth / (rx + ry) / 2.0 * 5;
+	const double cx = (A[0].x + job->translation.x) * job->scale.x;
+	const double cy = (A[0].y + job->translation.y) * job->scale.y;
+	const double rx = (A[1].x - A[0].x) * job->scale.x;
+	const double ry = (A[1].y - A[0].y) * job->scale.y;
+	const double w = job->obj->penwidth / (rx + ry) / 2.0 * 5;
 
 	//draw rim (torus)
 	char *p = pov_color_as_str(job, job->obj->pencolor, 0.0);
@@ -743,7 +741,7 @@ gvrender_features_t render_features_pov = {
 	    | GVRENDER_DOES_MAP_BSPLINE
 	    | GVRENDER_NO_WHITE_BG
 	    | GVRENDER_DOES_TRANSFORM
-	    | GVRENDER_DOES_Z | GVRENDER_DOES_MAP_BSPLINE,
+	    | GVRENDER_DOES_Z,
 	4.0,			/* default pad - graph units */
 	pov_knowncolors,	/* knowncolors */
 	sizeof(pov_knowncolors) / sizeof(char *),	/* strings in knowncolors */
