@@ -1,7 +1,7 @@
 #include <iostream>
 #include <string>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 #include <fmt/format.h>
 
 #include "test_edge_node_overlap_utilities.h"
